From 59d4cbb660e9283b0800fbc57c8f2e90886de008 Mon Sep 17 00:00:00 2001
From: Thomas Munro <thomas.munro@enterprisedb.com>
Date: Thu, 24 Aug 2017 22:49:38 +1200
Subject: [PATCH] Fix harmless thinko in dsa.c.

Commit 16be2fd100199bdf284becfcee02c5eb20d8a11d added DSA_ALLOC_HUGE,
DSA_ALLOC_ZERO and DSA_ALLOC_NO_OOM which have the same numerical values
and meanings as the similarly named MCXT_... macros.  In one place we
accidentally used MCXT_ALLOC_NO_OOM when DSA_ALLOC_NO_OOM is wanted,
so tidy that up.

Author: Thomas Munro
---
 src/backend/utils/mmgr/dsa.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/backend/utils/mmgr/dsa.c b/src/backend/utils/mmgr/dsa.c
index b3327f676b..fe62788188 100644
--- a/src/backend/utils/mmgr/dsa.c
+++ b/src/backend/utils/mmgr/dsa.c
@@ -707,7 +707,7 @@ dsa_allocate_extended(dsa_area *area, Size size, int flags)
 			dsa_free(area, span_pointer);
 
 			/* Raise error unless asked not to. */
-			if ((flags & MCXT_ALLOC_NO_OOM) == 0)
+			if ((flags & DSA_ALLOC_NO_OOM) == 0)
 				ereport(ERROR,
 						(errcode(ERRCODE_OUT_OF_MEMORY),
 						 errmsg("out of memory"),
-- 
2.13.2

